/* Example 5.1

 Statistical Methods in Biology: Design and Analysis of Experiments and Regression
 by S.J. Welham, S.A. Gezan, S.J. Clark & A. Mead (2014)
 Chapman & Hall/CRC Press, Boca Raton, Florida. ISBN: 978-1-4398-0878-8
 Version 1, 18/09/2014 

 Set working directory - change to location of your data file */

ods graphics on;

* Read data from working directory;
data CALCIUM;
  infile 'C:\DataFiles\CALCIUM.DAT' firstobs=2 expandtabs;
  input Pot Calcium $ Length;
run;
proc print data=CALCIUM;run;

* Sorting data by treatment;
proc sort data=CALCIUM;
  by Calcium;
run;

* Example 5.1A;

* One-way ANOVA (and save simple residuals);
proc glm data=CALCIUM;
  class Calcium;
  model Length = Calcium;  
  output out=RESID r=SimpleRes student=StdRes p=Pred;
run;
proc print data=RESID;run;

* Observed and fitted values; # NEEDS SOME FIXING;
axis1 label=('Total root length');
axis2 label=('Calcium concentration');
symbol value=dot interpol=none;
proc gplot data=RESID;
  plot (Pred Length)*Calcium / overlay vaxis=axis1 haxis=axis2;
run;

* Plot simple residuals;
axis1 label=('Simple residual');
axis2 label=('Calcium concentration');
symbol value=dot interpol=none;
proc gplot data=RESID;
  plot SimpleRes*Calcium / vaxis=axis1 haxis=axis2 vref=0;
run;

* Example 5.1B;

* Plot of  standardized residuals against fitted (predicted) values;
axis1 label=('Standardized residual');
axis2 label=('Fitted value');
symbol value=dot interpol=none;
proc gplot data=RESID;
  plot StdRes*Pred / vaxis=axis1 haxis=axis2 vref=0;
run;

* Plot of absolute standardized residuals against fitted values;
data RESID; set RESID;
  AbsRes=abs(StdRes);   * Absolute residuals;
run;

axis1 label=('|Standardized residual|');
axis2 label=('Fitted value');
symbol value=dot interpol=none;
proc gplot data=RESID;
  plot AbsRes*Pred / vaxis=axis1 haxis=axis2;
run;

* Example 5.1C;

* Index plot: standardized residuals against pot number;

* Sorting data by Pot;
proc sort data=RESID;
  by Pot;
run;
data RESID; set RESID;
  PrevRes=lag1(StdRes); * Lagged residuals;
run;

axis1 label=('Standardized residual');
axis2 label=('Pot number'); * order=(1 to 32);
symbol value=dot interpol=join;
proc gplot data=RESID;
  plot StdRes*Pot / vaxis=axis1 haxis=axis2 vref=0 href=0;
run;

* Plot of standardized residuals against previous standardized residuals;
axis1 label=('Standardized residual');
axis2 label=('Previous standardized residual'); * order=(1 to 32);
symbol value=dot interpol=none;
proc gplot data=RESID;
  plot StdRes*PrevRes / vaxis=axis1 haxis=axis2 vref=0 href=0;
run;

* Example 5.1D;

* Plot of  standardized residuals against fitted (predicted) values;
axis1 label=('Standardized residual');
axis2 label=('Fitted value');
symbol value=dot interpol=none;
proc gplot data=RESID;
  plot StdRes*Pred / vaxis=axis1 haxis=axis2 vref=0;
run;

* Plot of absolute standardized residuals against fitted values;
data RESID; set RESID;
  AbsRes=abs(StdRes);   * Absolute residuals;
run;

axis1 label=('|Standardized residual|');
axis2 label=('Fitted value');
symbol value=dot interpol=none;
proc gplot data=RESID;
  plot AbsRes*Pred / vaxis=axis1 haxis=axis2;
run;

* Plot Histogram and Normal Plot of standardized residuals;
proc univariate data=RESID noprint;
  histogram StdRes / normal;
  qqplot StdRes / normal href=0 vref=0;
run;

* SAS provides with a composite set of Diagnostic plots;
proc glm data=CALCIUM plots=DIAGNOSTICS;
  class Calcium;
  model Length = Calcium;  
  output out=RESID r=SimpleRes student=StdRes p=Pred;
run;

* Example 5.1E;

* Homogeneity of variances test (Bartlett's Test);
proc glm data=CALCIUM;
  class Calcium;
  model Length = Calcium;  
  means Calcium / hovtest=bartlett; 
run;

