/* Example 6.1

 Statistical Methods in Biology: Design and Analysis of Experiments and Regression
 by S.J. Welham, S.A. Gezan, S.J. Clark & A. Mead (2014)
 Chapman & Hall/CRC Press, Boca Raton, Florida. ISBN: 978-1-4398-0878-8
 Data from Rothamsted Research (A. Karp)
 Version 1, 19/09/2014 "

 Set working directory - change to location of your data file */

ods graphics on;

* Read data from working directory;
data BEETLES;
  infile 'C:\DataFiles\BEETLES.DAT' firstobs=2 expandtabs;
  input DFemale Treatment $ Species $ MateType $ Eggs;
run;
proc print data=BEETLES;run;

* Example 6.1A;

* Transforming the data to log scale;
data BEETLES; set BEETLES;
  logEggs=log10(Eggs);
run;

* Histograms of original data and log-transformed data;
proc univariate data=BEETLES noprint;
  histogram Eggs / normal;
  histogram logEggs / normal; 
run;

* One-way ANOVA without transformation with residual plots;
proc glm data=BEETLES plots=DIAGNOSTICS;
  class Treatment;
  model Eggs = Treatment;  
run;

* One-way ANOVA log-transformed data with residual plots;
proc glm data=BEETLES plots=DIAGNOSTICS;
  class Treatment;
  model logEggs = Treatment;  
  lsmeans Treatment / stderr cl alpha=0.05 out=LSA;
  ods output LSMeans=PREDMEANS;
run;

* Example 6.1B;

* Back-transform treatment means with 95% confidence limits;
data PREDMEANS; set PREDMEANS;
  btmeans=10**LSMean;
  btlower=10**(lsmean-tinv(0.975,36)*stderr);
  btupper=10**(lsmean+tinv(0.975,36)*stderr);
run;
proc print data=PREDMEANS;run;

* Example 6.1C;

* Report SEDs and LSDs and print differences between means for treatments 1 and 4;
proc glm data=BEETLES;
  class Treatment;
  model logEggs = Treatment / clparm;  
  means Treatment / lsd cldiff;
  estimate 'Diff trt1-trt4' Treatment -1 0 0 1;
run;
